# AUTOGENERATED! DO NOT EDIT! File to edit: 99_test.ipynb (unless otherwise specified).

__all__ = ['test_grid_search']

# Cell
from .core import grid_search

# Cell
def test_grid_search():
    generator = grid_search(x_range=[0, 1], y_range=[0, 1])
    assert list(next(generator)) == [0.0, 1.0]
    assert list(next(generator)) == [1.0, 1.0]
    assert list(next(generator)) == [0.0, 0.0]
    assert list(next(generator)) == [1.0, 0.0]
    assert list(next(generator)) == [0.5, 1.0]